# Conformal Regressor

A module for producing conformal predictions using regression

::: photonai_conformal.mapie_wrapper.ConformalRegressor.__init__
    rendering:
        show_root_toc_entry: False